function [PBest, CostBest, CovP] = MLE3Optimization(PBest,x,omega,Tm,stdTm,options,idxFree)

% Copyright (c) 2015 Matthijs van Berkel, Gerd Vandersteen
% All rights reserved.
% Software can be used freely for non-commercial applications only. 
% If used in publications please reference 
% [1] van Berkel, M., Vandersteen, G., Geerardyn, E., Pintelon, R., Zwart, H.J. and de Baar, M. R., 2014. Frequency domain sample maximum likelihood estimation for spatially dependent parameter estimation in PDEs, Automatica 50(8): 2113  2119. DOI: 10.1016/j.automatica.2014.05.027

% Compute the MLE error vector and the Jaobian matrix

if (nargin < 7)
    idxFree=[];
end
if isempty(idxFree)
    idxFree = 1:length(PBest);
end

[e,J]=MLE3cost(PBest,x,omega,Tm,stdTm); 
CostBest = real(e'*e);
            lambda0 = norm(J);

counter = 0;
lambda = 0;

while ((counter < options.maxNbfOfSteps) & (lambda < 1e10*lambda0));
    % While the cost in decreasing, perform a Newton-Gauss
    % optimization step.
    counter = counter + 1;
    
    % Compute the necessary step.
    if (lambda ~= 0)
        % Levenberg-Marquart
        dP = - [real(J(:,idxFree)); imag(J(:,idxFree)); lambda*eye(length(idxFree))]\[real(e); imag(e); zeros(length(idxFree), 1)];
    else
        % Gauss-Newton.
        dP = - [real(J(:,idxFree)); imag(J(:,idxFree))]\[real(e); imag(e)];
    end
    
    PNew = PBest;
    PNew(idxFree) = PBest(idxFree)+dP;
    
    % Evaluate the new optimized point.
    [eNew,JNew]=MLE3cost(PNew,x,omega,Tm,stdTm);
    
    %    NewCost = real(NewJ(:,end)'*NewJ(:,end));
    CostNew = real(eNew'*eNew);
 
    % If the step is succesful: take the step and decrease lambda
    if (CostNew < CostBest)
        J = JNew;
        e = eNew;
        PBest = PNew;
        CostBest = CostNew;
        lambda = lambda / 3;
    else
        % If the step is not succesful: use lamdba to controle the stepsize
        if (lambda == 0)
            lambda0 = norm(JNew);
            lambda = lambda0;
        else
            lambda = lambda * 10;
        end
    end
end


    J_RI=[real(J(:,idxFree)); imag(J(:,idxFree))];
    CovP = zeros(length(PBest),length(PBest));
    CovP(idxFree,idxFree) = 0.5*inv(J_RI'*J_RI);

fprintf('counter = %d ,lambda = %d ,cond = %d, \n',counter,lambda,cond(J));

