function [e,J] = MLE3cost(P,x,omega,U,VarCovar)
%% Computation of the ML cost function for following model
%   P is vector of coefficients P = [a,b,c] (real-valued)
%   x positions of the measurement [m]
%   U real measurements temperature (frequency dependent)
%   VarCovar variances temperature meaurements (frequency dependent)
%   omega is the frequency vector [rad/s]

% Copyright (c) 2015 Matthijs van Berkel, Gerd Vandersteen
% All rights reserved.
% Software can be used freely for non-commercial applications only. 
% If used in publications please reference 
% [1] van Berkel, M., Vandersteen, G., Geerardyn, E., Pintelon, R., Zwart, H.J. and de Baar, M. R., 2014. Frequency domain sample maximum likelihood estimation for spatially dependent parameter estimation in PDEs, Automatica 50(8): 2113  2119. DOI: 10.1016/j.automatica.2014.05.027


% e=zeros(length(U(:,1)),1); % initiate memory space
 J=zeros(length(omega),3);

[Eps,dEpsda,dEpsdb,dEpsdc] = SlabCostFunction(P(1),P(2),P(3),x,omega,U,VarCovar);


e= Eps(:); % Cost function
J(:,1) = dEpsda(:); % Calculate Jacobian
J(:,2) = dEpsdb(:); % Calculate Jacobian
J(:,3) = dEpsdc(:); % Calculate Jacobian


end

