function [qk, Cvk] = ac2qk(PBest, CovP, c_x_rho, cw_x_rhow)
%
% Conversion parameters [a,c] towards the physical parameters v and k,
% together with the covariance matrix.
%
% Copyright (c) 2015 Uwe Schneidewind, Matthijs van Berkel, Gerd Vandersteen, 
% All rights reserved.
% Software can be used freely for non-commercial applications only. 
% If used in publications please reference 
% [1] van Berkel, M., Vandersteen, G., Geerardyn, E., Pintelon, R., Zwart, H.J. and de Baar, M. R., 2014. Frequency domain sample maximum likelihood estimation for spatially dependent parameter estimation in PDEs, Automatica 50(8): 2113  2119. DOI: 10.1016/j.automatica.2014.05.027
% [2] Schneidewind, U., van Berkel, M., Anibas, C., Vandersteen, G., Schmidt, C., Joris, I., Seuntjens, P., Batelaan, O., and Zwart, H.J., 2016. LPMLE3 - A Novel Method to Quantify Vertical Water Fluxes in Streambeds Using Heat as a Tracer, Water Resources Research

a = PBest(1); c = PBest(3);

qk = [-c_x_rho/cw_x_rhow*2*a/c; c_x_rho/c]; % transform parameters

J = [-2*c_x_rho/cw_x_rhow/c c_x_rho/cw_x_rhow*2*a/c^2; ...
    0                  -c_x_rho/c^2]; % Calculate Jacobian

Cvk = J*CovP([1;3],[1;3])*J'; % transform covariance matrix


