function [dVardtheta] = dVardtheta(G1,G2,dG1dt,dG2dt,VarCovar)
%Calculates the derivative of the variance
%   [dVardtheta] = dVardtheta(G1,G2,dG1dt,dG2dt,VarCovar)
%    with VarCovar = [Varyy,Varu1u1,Varu2u2,Covaryu1,Covaryu2,Covaru1u2];

% Copyright (c) 2015 Matthijs van Berkel, Gerd Vandersteen
% All rights reserved.
% Software can be used freely for non-commercial applications only. 
% If used in publications please reference 
% [1] van Berkel, M., Vandersteen, G., Geerardyn, E., Pintelon, R., Zwart, H.J. and de Baar, M. R., 2014. Frequency domain sample maximum likelihood estimation for spatially dependent parameter estimation in PDEs, Automatica 50(8): 2113  2119. DOI: 10.1016/j.automatica.2014.05.027


G1 = G1(:); G2 = G2(:); dG1dt = dG1dt(:); dG2dt = dG2dt(:);

% Calculate necessary derivatives of absolute value 
dabsG1dt = G1.*conj(dG1dt)+conj(G1).*dG1dt;
dabsG2dt = G2.*conj(dG2dt)+conj(G2).*dG2dt;

% Calculate derivative of variance
dVardtheta = dabsG1dt.*VarCovar(:,2)+dabsG2dt.*VarCovar(:,3)+...
         2*real(VarCovar(:,6).*(G1.*conj(dG2dt)+conj(G2).*dG1dt))...
        -2*real(conj(dG1dt).*VarCovar(:,4)+conj(dG2dt).*VarCovar(:,5));
   
end

% dVarda = dabsG1dt*Varu1u1+dabsG2dt*Varu2u2+...
%          2*real(Covaru1u2*(G1*dconjG2dt+conj(G2)*dG1dt))...
%         -2*real(dconjG1dt*Covaryu1+dconjG2dt*Covaryu2);