function [T, dTda, dTdb, dTdc] = ComputeTF(a,b,c,x,w)
%%
% Evaluates the transfer function
%  d^2 T/dx^2 + a dT/dx + b + i w c = 0 with a, b and c real valued and its derivatives
%
% Gerd Vandersteen Vrije Universiteit Brussel / Dept ELEC

x=x(:);
w=w(:).';

a = a / 2;

tmp1=-sqrt(a.^2 - (b + 1i.*w.*c));
dtmp1darg=0.5./tmp1;
lambda = tmp1 - a; % -b +/- sqrt(a^2 - b - i w c)
T=exp(kron(lambda,x));
dTda = T.*kron((2*a.*dtmp1darg - 1), x);
dTdb = - T.*kron(dtmp1darg, x);
dTdc = - T.*kron(1i.*w.*dtmp1darg, x);

dTda = dTda / 2;

