function [PBest, CostBest, CovP] = MLEOptimization(PBest,x,omega,Tm,stdTm,options, idxFree)
% Performs a simple Levenberg-Marquart / Gauss-Newton optimization
%
% Gerd Vandersteen Vrije Universiteit Brussel / Dept ELEC

if (nargin < 7)
    idxFree=[];
end
if isempty(idxFree)
    idxFree = 1:length(PBest);
end

[e,J]=MLcost(PBest,x,omega,Tm,stdTm);
CostBest = real(e'*e);
lambda0 = norm(J);

counter = 0;
lambda = 0;

while ((counter < options.maxNbfOfSteps) & (lambda < 1e10*lambda0))
    % While the cost in decreasing, perform a Newton-Gauss
    % optimization step.
    counter = counter + 1;
    
    % Compute the necessary step.
    if (lambda ~= 0)
        % Levenberg-Marquart
        dP = - [real(J(:,idxFree)); imag(J(:,idxFree)); lambda*eye(length(idxFree))]\[real(e); imag(e); zeros(length(idxFree), 1)];
    else
        % Gauss-Newton.
        dP = - [real(J(:,idxFree)); imag(J(:,idxFree))]\[real(e); imag(e)];
    end
    PNew = PBest;
    PNew(idxFree) = PBest(idxFree)+dP;
    
    % Evaluate the new optimized point.
    [eNew,JNew]=MLcost(PNew,x,omega,Tm,stdTm);
    
    CostNew = real(eNew'*eNew);
    
    % If the step is succesful: take the step and decrease lambda
    if (CostNew < CostBest)
        J = JNew;
        e = eNew;
        PBest = PNew;
        CostBest = CostNew;
        lambda = lambda / 3;
    else
        % If the step is not succesful: use lamdba to controle the stepsize
        if (lambda == 0)
            lambda0 = norm(JNew);
            lambda = lambda0;
        else
            lambda = lambda * 10;
        end
    end
end

if (1)
    J_RI=[real(J(:,idxFree)); imag(J(:,idxFree))];
    CovP = zeros(size(PBest));
    CovP(idxFree,idxFree) = 0.5*inv(J_RI'*J_RI);
else
    J_RI=[real(J); imag(J)];
    CovP = pinv(J_RI'*J_RI);
end


